<?php

/**
 * @file
 * WeChat Request Msg Type editing UI.
 */

/**
 * Generates the wechat request msg type editing form.
 */
function wechat_request_msg_type_form($form, &$form_state, $msg_type, $op = 'edit') {

  if ($op == 'clone') {
    $msg_type->label .= ' (cloned)';
    $msg_type->type = '';
  }

  $form['label'] = array(
    '#title' => t('Label'),
    '#type' => 'textfield',
    '#default_value' => $msg_type->label,
    '#description' => t('The human-readable name of this message type.'),
    '#required' => TRUE,
    '#size' => 30,
  );
  // Machine-readable type name.
  $form['type'] = array(
    '#type' => 'machine_name',
    '#default_value' => isset($msg_type->type) ? $msg_type->type : '',
    '#maxlength' => 32,
    '#disabled' => $msg_type->isLocked() && $op != 'clone',
    '#machine_name' => array(
      'exists' => 'wechat_request_msg_get_types',
      'source' => array('label'),
    ),
    '#description' => t('A unique machine-readable name for this message type. It must only contain lowercase letters, numbers, and underscores.'),
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#weight' => 40,
  );
  $form['weight'] = array(
    '#type' => 'weight',
    '#title' => t('Weight'),
    '#default_value' => $msg_type->weight,
    '#description' => t('When showing message types, those with lighter (smaller) weights get listed before message types with heavier (larger) weights.'),
    '#weight' => 10,
  );

  if (!$msg_type->isLocked() && $op != 'add' && $op != 'clone') {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#weight' => 45,
      '#limit_validation_errors' => array(),
      '#submit' => array('wechat_request_msg_type_form_submit_delete'),
    );
  }
  return $form;
}

/**
 * Form API submit callback for the type form.
 */
function wechat_request_msg_type_form_submit(&$form, &$form_state) {
  $wechat_request_msg_type = entity_ui_form_submit_build_entity($form, $form_state);
  // Save and go back.
  $wechat_request_msg_type->save();
  $form_state['redirect'] = 'admin/structure/wechat-request-messages';
}

/**
 * Form API submit callback for the delete button.
 */
function wechat_request_msg_type_form_submit_delete(&$form, &$form_state) {
  $form_state['redirect'] = 'admin/structure/wechat-request-messages/manage/' . $form_state['msg_type']->type . '/delete';
}
