<?php

/**
 * @file
 * Wechat_response_msg_type admin pages.
 */

/**
 * Generates the profile type editing form.
 */
function wechat_response_msg_type_form($form, &$form_state, $message_type, $op = 'edit') {
  // Print debug($message_type);
  if ($op == 'clone') {
    $message_type->label .= ' (cloned)';
    $message_type->type = '';
  }

  $form['label'] = array(
    '#title' => t('Label'),
    '#type' => 'textfield',
    '#default_value' => $message_type->label,
    '#description' => t('The human-readable name of this message type.'),
    '#required' => TRUE,
    '#size' => 30,
  );
  $form['type'] = array(
    '#type' => 'machine_name',
    '#default_value' => isset($message_type->type) ? $message_type->type : '',
    '#maxlength' => 32,
    '#disabled' => $message_type->isLocked() && $op != 'clone',
    '#machine_name' => array(
      'exists' => 'wechat_response_message_get_types',
      'source' => array('label'),
    ),
    '#description' => t('A unique machine-readable name for this message type.
    It must only contain lowercase letters, numbers, and underscores.'),
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save message type'),
    '#weight' => 40,
    '#submit' => array('wechat_response_message_type_form_submit'),
  );
  $form['weight'] = array(
    '#type' => 'weight',
    '#title' => t('Weight'),
    '#default_value' => $message_type->weight,
    '#description' => t('When showing message types, those with lighter
    (smaller) weights get listed before message types with heavier (larger)
    weights.'),
    '#weight' => 10,
  );

  if (!$message_type->isLocked() && $op != 'add' && $op != 'clone') {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete message type'),
      '#weight' => 45,
      '#limit_validation_errors' => array(),
      '#submit' => array('wechat_response_message_type_form_submit_delete'),
    );
  }
  return $form;
}

/**
 * Form API submit callback for the type form.
 */
function wechat_response_msg_type_form_submit(&$form, &$form_state) {
  $wechat_response_msg_type = entity_ui_form_submit_build_entity($form, $form_state);
  // Save and go back.
  // print debug($wechat_response_message_type);
  $wechat_response_msg_type->save();
  $form_state['redirect'] = 'admin/structure/response-messages';
}

/**
 * Form API submit callback for the delete button.
 */
function wechat_response_msg_type_form_submit_delete(&$form, &$form_state) {
  $form_state['redirect'] = 'admin/structure/wechat-request-messages/manage/' . $form_state['message_type']->type . '/delete';
}
